===============================
lazysecrets
===============================


.. image:: https://img.shields.io/pypi/v/lazysecrets.svg
        :target: https://pypi.python.org/pypi/lazysecrets

.. image:: https://img.shields.io/travis/rev112/lazysecrets.svg
        :target: https://travis-ci.org/rev112/lazysecrets

.. image:: https://readthedocs.org/projects/lazysecrets/badge/?version=latest
        :target: https://lazysecrets.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/rev112/lazysecrets/shield.svg
     :target: https://pyup.io/repos/github/rev112/lazysecrets/
     :alt: Updates


Short description here


* Free software: MIT license
* Documentation: https://lazysecrets.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

